@@ -1,6 +1,6 @@
 // This module implements the QsciLexerPython class.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -24,11 +24,6 @@
 // http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 // or contact the sales department at sales@riverbankcomputing.com.
 // 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
-// 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -50,8 +45,9 @@ const char *QsciLexerPython::keywordClass =
 // The ctor.
 QsciLexerPython::QsciLexerPython(QObject *parent, const char *name)
     : QsciLexer(parent, name),
-      fold_comments(false), fold_quotes(false), indent_warn(NoWarning),
-      v2_unicode(true), v3_binary_octal(true), v3_bytes(true)
+      fold_comments(false), fold_compact(true), fold_quotes(false),
+      indent_warn(NoWarning), strings_over_newline(false), v2_unicode(true),
+      v3_binary_octal(true), v3_bytes(true)
 {
 }
 
@@ -305,8 +301,10 @@ QColor QsciLexerPython::defaultPaper(int style) const
 void QsciLexerPython::refreshProperties()
 {
     setCommentProp();
+    setCompactProp();
     setQuotesProp();
     setTabWhingeProp();
+    setStringsOverNewlineProp();
     setV2UnicodeProp();
     setV3BinaryOctalProp();
     setV3BytesProp();
@@ -327,6 +325,13 @@ bool QsciLexerPython::readProperties(QSettings &qs,const QString &prefix)
     else
         rc = false;
 
+    flag = qs.readBoolEntry(prefix + "foldcompact", true, &ok);
+
+    if (ok)
+        fold_compact = flag;
+    else
+        rc = false;
+
     flag = qs.readBoolEntry(prefix + "foldquotes", false, &ok);
 
     if (ok)
@@ -341,6 +346,13 @@ bool QsciLexerPython::readProperties(QSettings &qs,const QString &prefix)
     else
         rc = false;
 
+    flag = qs.readBoolEntry(prefix + "stringsovernewline", false, &ok);
+
+    if (ok)
+        strings_over_newline = flag;
+    else
+        rc = false;
+
     flag = qs.readBoolEntry(prefix + "v2unicode", true, &ok);
 
     if (ok)
@@ -374,12 +386,18 @@ bool QsciLexerPython::writeProperties(QSettings &qs,const QString &prefix) const
     if (!qs.writeEntry(prefix + "foldcomments", fold_comments))
         rc = false;
 
+    if (!qs.writeEntry(prefix + "foldcompact", fold_compact))
+        rc = false;
+
     if (!qs.writeEntry(prefix + "foldquotes", fold_quotes))
         rc = false;
 
     if (!qs.writeEntry(prefix + "indentwarning", (int)indent_warn))
         rc = false;
 
+    if (!qs.writeEntry(prefix + "stringsovernewline", strings_over_newline))
+        rc = false;
+
     if (!qs.writeEntry(prefix + "v2unicode", v2_unicode))
         rc = false;
 
@@ -393,13 +411,6 @@ bool QsciLexerPython::writeProperties(QSettings &qs,const QString &prefix) const
 }
 
 
-// Return true if comments can be folded.
-bool QsciLexerPython::foldComments() const
-{
-    return fold_comments;
-}
-
-
 // Set if comments can be folded.
 void QsciLexerPython::setFoldComments(bool fold)
 {
@@ -416,10 +427,19 @@ void QsciLexerPython::setCommentProp()
 }
 
 
-// Return true if quotes can be folded.
-bool QsciLexerPython::foldQuotes() const
+// Set if folds are compact.
+void QsciLexerPython::setFoldCompact(bool fold)
 {
-    return fold_quotes;
+    fold_compact = fold;
+
+    setCompactProp();
+}
+
+
+// Set the "fold.compact" property.
+void QsciLexerPython::setCompactProp()
+{
+    emit propertyChanged("fold.compact",(fold_compact ? "1" : "0"));
 }
 
 
@@ -439,13 +459,6 @@ void QsciLexerPython::setQuotesProp()
 }
 
 
-// Return the indentation warning.
-QsciLexerPython::IndentationWarning QsciLexerPython::indentationWarning() const
-{
-    return indent_warn;
-}
-
-
 // Set the indentation warning.
 void QsciLexerPython::setIndentationWarning(QsciLexerPython::IndentationWarning warn)
 {
@@ -462,10 +475,19 @@ void QsciLexerPython::setTabWhingeProp()
 }
 
 
-// Return true if v2 unicode string literals are allowed.
-bool QsciLexerPython::v2UnicodeAllowed() const
+// Set if string literals can span newlines.
+void QsciLexerPython::setStringsOverNewlineAllowed(bool allowed)
 {
-    return v2_unicode;
+    strings_over_newline = allowed;
+
+    setStringsOverNewlineProp();
+}
+
+
+// Set the "lexer.python.strings.u" property.
+void QsciLexerPython::setStringsOverNewlineProp()
+{
+    emit propertyChanged("lexer.python.strings.over.newline", (strings_over_newline ? "1" : "0"));
 }
 
 
@@ -485,13 +507,6 @@ void QsciLexerPython::setV2UnicodeProp()
 }
 
 
-// Return true if v3 binary and octal literals are allowed.
-bool QsciLexerPython::v3BinaryOctalAllowed() const
-{
-    return v3_binary_octal;
-}
-
-
 // Set if v3 binary and octal literals are allowed.
 void QsciLexerPython::setV3BinaryOctalAllowed(bool allowed)
 {
@@ -508,13 +523,6 @@ void QsciLexerPython::setV3BinaryOctalProp()
 }
 
 
-// Return true if v3 bytes string literals are allowed.
-bool QsciLexerPython::v3BytesAllowed() const
-{
-    return v3_bytes;
-}
-
-
 // Set if v3 bytes string literals are allowed.
 void QsciLexerPython::setV3BytesAllowed(bool allowed)
 {
