@@ -1,6 +1,6 @@
 // This module implements the QsciAPIs class.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -24,11 +24,6 @@
 // http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 // or contact the sales department at sales@riverbankcomputing.com.
 // 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
-// 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -73,17 +68,28 @@ struct QsciAPIsPrepared
     // The raw API information.
     QStringList raw_apis;
 
-    QStringList apiWords(int api_idx, const QStringList &wseps) const;
+    QStringList apiWords(int api_idx, const QStringList &wseps,
+            bool strip_image) const;
     static QString apiBaseName(const QString &api);
 };
 
 
 
 // Return a particular API entry as a list of words.
-QStringList QsciAPIsPrepared::apiWords(int api_idx, const QStringList &wseps) const
+QStringList QsciAPIsPrepared::apiWords(int api_idx, const QStringList &wseps,
+        bool strip_image) const
 {
     QString base = apiBaseName(raw_apis[api_idx]);
 
+    // Remove any embedded image reference if necessary.
+    if (strip_image)
+    {
+        int tail = base.indexOf('?');
+
+        if (tail >= 0)
+            base.truncate(tail);
+    }
+
     if (wseps.isEmpty())
         return QStringList(base);
 
@@ -178,7 +184,7 @@ void QsciAPIsWorker::run()
         if (abort)
             break;
 
-        QStringList words = prepared->apiWords(a, wseps);
+        QStringList words = prepared->apiWords(a, wseps, true);
 
         for (int w = 0; w < words.count(); ++w)
         {
@@ -273,9 +279,9 @@ void QsciAPIs::clear()
 
 
 // Clear out all API information.
-bool QsciAPIs::load(const QString &fname)
+bool QsciAPIs::load(const QString &filename)
 {
-    QFile f(fname);
+    QFile f(filename);
 
     if (!f.open(QIODevice::ReadOnly))
         return false;
@@ -408,7 +414,7 @@ bool QsciAPIs::originStartsWith(const QString &path, const QString &wsep)
     // follows in the origin is either a word separator or a (.
     QString tail = orig.mid(path.length());
 
-    return (tail.startsWith(wsep) || tail.at(0) == '(');
+    return (!tail.isEmpty() && (tail.startsWith(wsep) || tail.at(0) == '('));
 }
 
 
@@ -602,7 +608,7 @@ void QsciAPIs::addAPIEntries(const WordIndexList &wl, bool complete,
     {
         const WordIndex &wi = wl[w];
 
-        QStringList api_words = prep->apiWords(wi.first, wseps);
+        QStringList api_words = prep->apiWords(wi.first, wseps, false);
 
         int idx = wi.second;
 
@@ -704,7 +710,7 @@ QStringList QsciAPIs::callTips(const QStringList &context, int commas,
             for (int i = 0; i < wil->count(); ++i)
             {
                 const WordIndex &wi = (*wil)[i];
-                QStringList awords = prep->apiWords(wi.first, wseps);
+                QStringList awords = prep->apiWords(wi.first, wseps, true);
 
                 // Check the word is the function name and not part of any
                 // context.
@@ -776,9 +782,9 @@ void QsciAPIs::cancelPreparation()
 
 
 // Check that a prepared API file exists.
-bool QsciAPIs::isPrepared(const QString &fname) const
+bool QsciAPIs::isPrepared(const QString &filename) const
 {
-    QString pname = prepName(fname);
+    QString pname = prepName(filename);
 
     if (pname.isEmpty())
         return false;
@@ -790,9 +796,9 @@ bool QsciAPIs::isPrepared(const QString &fname) const
 
 
 // Load the prepared API information.
-bool QsciAPIs::loadPrepared(const QString &fname)
+bool QsciAPIs::loadPrepared(const QString &filename)
 {
-    QString pname = prepName(fname);
+    QString pname = prepName(filename);
 
     if (pname.isEmpty())
         return false;
@@ -862,9 +868,9 @@ bool QsciAPIs::loadPrepared(const QString &fname)
 
 
 // Save the prepared API information.
-bool QsciAPIs::savePrepared(const QString &fname) const
+bool QsciAPIs::savePrepared(const QString &filename) const
 {
-    QString pname = prepName(fname, true);
+    QString pname = prepName(filename, true);
 
     if (pname.isEmpty())
         return false;
@@ -905,11 +911,11 @@ QString QsciAPIs::defaultPreparedName() const
 
 
 // Return the name of a prepared API file.
-QString QsciAPIs::prepName(const QString &fname, bool mkpath) const
+QString QsciAPIs::prepName(const QString &filename, bool mkpath) const
 {
     // Handle the tivial case.
-    if (!fname.isEmpty())
-        return fname;
+    if (!filename.isEmpty())
+        return filename;
 
     QString pdname;
     char *qsci = getenv("QSCIDIR");
@@ -938,7 +944,7 @@ QStringList QsciAPIs::installedAPIFiles() const
     QString qtdir = QLibraryInfo::location(QLibraryInfo::DataPath);
 
     QDir apidir = QDir(QString("%1/qsci/api/%2").arg(qtdir).arg(lexer()->lexer()));
-    QStringList fnames;
+    QStringList filenames;
 
     QStringList filters;
     filters << "*.api";
@@ -946,7 +952,7 @@ QStringList QsciAPIs::installedAPIFiles() const
     QFileInfoList flist = apidir.entryInfoList(filters, QDir::Files, QDir::IgnoreCase);
 
     foreach (QFileInfo fi, flist)
-        fnames << fi.absoluteFilePath();
+        filenames << fi.absoluteFilePath();
 
-    return fnames;
+    return filenames;
 }
