@@ -1,6 +1,6 @@
 // This module implements the QsciLexerHTML class.
 //
-// Copyright (c) 2008 Riverbank Computing Limited <info@riverbankcomputing.com>
+// Copyright (c) 2011 Riverbank Computing Limited <info@riverbankcomputing.com>
 // 
 // This file is part of QScintilla.
 // 
@@ -24,11 +24,6 @@
 // http://trolltech.com/products/qt/licenses/licensing/licensingoverview
 // or contact the sales department at sales@riverbankcomputing.com.
 // 
-// This file is provided "AS IS" with NO WARRANTY OF ANY KIND,
-// INCLUDING THE WARRANTIES OF DESIGN, MERCHANTABILITY AND FITNESS FOR
-// A PARTICULAR PURPOSE. Trolltech reserves all rights not expressly
-// granted herein.
-// 
 // This file is provided AS IS with NO WARRANTY OF ANY KIND, INCLUDING THE
 // WARRANTY OF DESIGN, MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.
 
@@ -47,7 +42,8 @@
 QsciLexerHTML::QsciLexerHTML(QObject *parent)
     : QsciLexer(parent),
       fold_compact(true), fold_preproc(true), case_sens_tags(false),
-      fold_script_comments(false), fold_script_heredocs(false)
+      fold_script_comments(false), fold_script_heredocs(false),
+      django_templates(false), mako_templates(false)
 {
 }
 
@@ -72,10 +68,17 @@ const char *QsciLexerHTML::lexer() const
 }
 
 
+// Return the auto-completion fillup characters.
+const char *QsciLexerHTML::autoCompletionFillups() const
+{
+    return "/>";
+}
+
+
 // Return the string of characters that comprise a word.
 const char *QsciLexerHTML::wordCharacters() const
 {
-        return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-";
+    return "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789_-";
 }
 
 
@@ -1021,6 +1024,8 @@ void QsciLexerHTML::refreshProperties()
     setCaseSensTagsProp();
     setScriptCommentsProp();
     setScriptHeredocsProp();
+    setDjangoProp();
+    setMakoProp();
 }
 
 
@@ -1034,6 +1039,8 @@ bool QsciLexerHTML::readProperties(QSettings &qs,const QString &prefix)
     case_sens_tags = qs.value(prefix + "casesensitivetags", false).toBool();
     fold_script_comments = qs.value(prefix + "foldscriptcomments", false).toBool();
     fold_script_heredocs = qs.value(prefix + "foldscriptheredocs", false).toBool();
+    django_templates = qs.value(prefix + "djangotemplates", false).toBool();
+    mako_templates = qs.value(prefix + "makotemplates", false).toBool();
 
     return rc;
 }
@@ -1049,18 +1056,13 @@ bool QsciLexerHTML::writeProperties(QSettings &qs,const QString &prefix) const
     qs.setValue(prefix + "casesensitivetags", case_sens_tags);
     qs.setValue(prefix + "foldscriptcomments", fold_script_comments);
     qs.setValue(prefix + "foldscriptheredocs", fold_script_heredocs);
+    qs.setValue(prefix + "djangotemplates", django_templates);
+    qs.setValue(prefix + "makotemplates", mako_templates);
 
     return rc;
 }
 
 
-// Return true if tags are case sensitive.
-bool QsciLexerHTML::caseSensitiveTags() const
-{
-    return case_sens_tags;
-}
-
-
 // Set if tags are case sensitive.
 void QsciLexerHTML::setCaseSensitiveTags(bool sens)
 {
@@ -1077,13 +1079,6 @@ void QsciLexerHTML::setCaseSensTagsProp()
 }
 
 
-// Return true if folds are compact.
-bool QsciLexerHTML::foldCompact() const
-{
-    return fold_compact;
-}
-
-
 // Set if folds are compact
 void QsciLexerHTML::setFoldCompact(bool fold)
 {
@@ -1100,13 +1095,6 @@ void QsciLexerHTML::setCompactProp()
 }
 
 
-// Return true if preprocessor blocks can be folded.
-bool QsciLexerHTML::foldPreprocessor() const
-{
-    return fold_preproc;
-}
-
-
 // Set if preprocessor blocks can be folded.
 void QsciLexerHTML::setFoldPreprocessor(bool fold)
 {
@@ -1123,13 +1111,6 @@ void QsciLexerHTML::setPreprocProp()
 }
 
 
-// Return true if script comments can be folded.
-bool QsciLexerHTML::foldScriptComments() const
-{
-    return fold_script_comments;
-}
-
-
 // Set if script comments can be folded.
 void QsciLexerHTML::setFoldScriptComments(bool fold)
 {
@@ -1146,13 +1127,6 @@ void QsciLexerHTML::setScriptCommentsProp()
 }
 
 
-// Return true if script heredocs can be folded.
-bool QsciLexerHTML::foldScriptHeredocs() const
-{
-    return fold_script_heredocs;
-}
-
-
 // Set if script heredocs can be folded.
 void QsciLexerHTML::setFoldScriptHeredocs(bool fold)
 {
@@ -1167,3 +1141,35 @@ void QsciLexerHTML::setScriptHeredocsProp()
 {
     emit propertyChanged("fold.hypertext.heredoc",(fold_script_heredocs ? "1" : "0"));
 }
+
+
+// Set if Django templates are supported.
+void QsciLexerHTML::setDjangoTemplates(bool enable)
+{
+    django_templates = enable;
+
+    setDjangoProp();
+}
+
+
+// Set the "lexer.html.django" property.
+void QsciLexerHTML::setDjangoProp()
+{
+    emit propertyChanged("lexer.html.django", (django_templates ? "1" : "0"));
+}
+
+
+// Set if Mako templates are supported.
+void QsciLexerHTML::setMakoTemplates(bool enable)
+{
+    mako_templates = enable;
+
+    setMakoProp();
+}
+
+
+// Set the "lexer.html.mako" property.
+void QsciLexerHTML::setMakoProp()
+{
+    emit propertyChanged("lexer.html.mako", (mako_templates ? "1" : "0"));
+}
